@@ -1,31 +1,25 @@
 # -*- coding: utf-8 -*-
-import os
-import json
-import pickle as pickle
-import redis
 import itertools
+import json
 import logging
+import os
 import re
+from functools import reduce
 
 from mock import Mock
-
-from flask_login import current_user
-
 from mxcubecore import HardwareRepository as HWR
-
-from mxcubecore.model import queue_model_objects as qmo
-from mxcubecore.model import queue_model_enumerables as qme
-
 from mxcubecore import queue_entry as qe
+from mxcubecore.HardwareObjects.Gphl import GphlQueueEntry
+from mxcubecore.model import queue_model_enumerables as qme
+from mxcubecore.model import queue_model_objects as qmo
 from mxcubecore.queue_entry.base_queue_entry import QUEUE_ENTRY_STATUS
 
-from mxcubecore.HardwareObjects.Gphl import GphlQueueEntry
-
 from mxcubeweb.core.components.component_base import ComponentBase
-from mxcubeweb.core.util.convertutils import str_to_camel, str_to_snake
 from mxcubeweb.core.models.generic import SimpleNameValue
-
-from functools import reduce
+from mxcubeweb.core.util.convertutils import (
+    str_to_camel,
+    str_to_snake,
+)
 
 # Important: same constants as in constants.js
 QUEUE_PAUSED = "QueuePaused"
@@ -47,13 +41,14 @@ ORIGIN_MX3 = "MX3"
 class Queue(ComponentBase):
     def __init__(self, app, config):
         super().__init__(app, config)
+        self.init_queue_settings()
 
     def build_prefix_path_dict(self, path_list):
         prefix_path_dict = {}
 
         for path in path_list:
             try:
-                path, run_number, img_number = qmo.PathTemplate.interpret_path(path)
+                path, run_number, _ = qmo.PathTemplate.interpret_path(path)
             except ValueError:
                 logging.getLogger("MX3.HWR").info(
                     '[QUEUE] Warning, failed to interpret path: "%s", please check path'
@@ -68,7 +63,7 @@ class Queue(ComponentBase):
         return prefix_path_dict
 
     def get_run_number(self, pt):
-        # Path templates of files not yet written to to disk, we are only
+        # Path templates of files not yet written to disk, we are only
         # interested in the prefix path
 
         pt.run_number = HWR.beamline.queue_model.get_next_run_number(pt)
@@ -270,9 +265,7 @@ class Queue(ComponentBase):
         settings = {}
 
         for setting_name in [
-            "NUM_SNAPSHOTS",
             "REMEMBER_PARAMETERS_BETWEEN_SAMPLES",
-            "CENTRING_METHOD",
             "AUTO_ADD_DIFFPLAN",
         ]:
             settings[str_to_camel(setting_name)] = getattr(self.app, setting_name)
@@ -284,12 +277,15 @@ class Queue(ComponentBase):
             "queue": sample_order,
             "sampleList": self.app.lims.sample_list_get(current_queue=queue),
             "queueStatus": self.queue_exec_state(),
+            "numSnapshots": HWR.beamline.collect.get_property(
+                "num_snapshots", self.app.DEFAULT_NUM_SNAPSHOTS
+            ),
         }
 
         res.update(settings)
         return res
 
-    def _handle_task_node(self, sample_node, node, include_lims_data=False):
+    def _handle_task_node(self, sample_node, node):
         parameters = {
             **node.task_data.collection_parameters.dict(),
             **node.task_data.user_collection_parameters.dict(),
@@ -322,7 +318,6 @@ class Queue(ComponentBase):
             "queueID": node._node_id,
             "checked": node.is_enabled(),
             "state": self.get_node_state(node._node_id)[1],
-            "limsResultData": "",
         }
 
     def _handle_dc(self, sample_node, node, include_lims_data=False):
@@ -337,7 +332,7 @@ class Queue(ComponentBase):
         parameters.pop("centred_position")
 
         queueID = node._node_id
-        enabled, state = self.get_node_state(queueID)
+        _, state = self.get_node_state(queueID)
 
         parameters["subdir"] = os.path.join(
             *parameters["path"].split(HWR.beamline.session.raw_data_folder_name)[1:]
@@ -353,17 +348,6 @@ class Queue(ComponentBase):
             parameters["path"], parameters["fileName"]
         )
 
-        limsres = {}
-        lims_id = self.app.NODE_ID_TO_LIMS_ID.get(node._node_id, "null")
-
-        # Only add data from lims if explicitly asked for, since
-        # its a operation that can take some time.
-        if include_lims_data and HWR.beamline.lims.lims_rest:
-            limsres = HWR.beamline.lims.lims_rest.get_dc(lims_id)
-
-        # Always add link to data, (no request made)
-        limsres["limsTaskLink"] = self.app.lims.get_dc_link(lims_id)
-
         dtype_label = qme.EXPERIMENT_TYPE._fields[node.experiment_type]
         dtype_label = "OSCILLATION" if dtype_label == "NATIVE" else dtype_label
         dtype_label = (
@@ -382,7 +366,6 @@ class Queue(ComponentBase):
             "queueID": queueID,
             "checked": node.is_enabled(),
             "state": state,
-            "limsResultData": limsres,
         }
 
         return res
@@ -397,7 +380,7 @@ class Queue(ComponentBase):
         parameters["shape"] = node.shape
 
         queueID = node._node_id
-        enabled, state = self.get_node_state(queueID)
+        _, state = self.get_node_state(queueID)
 
         raw_data = HWR.beamline.session.raw_data_folder_name
         ddir = parameters["directory"]
@@ -415,17 +398,6 @@ class Queue(ComponentBase):
             parameters["directory"], parameters["fileName"]
         )
 
-        limsres = {}
-        lims_id = self.app.NODE_ID_TO_LIMS_ID.get(node._node_id, "null")
-
-        # Only add data from lims if explicitly asked for, since
-        # its a operation that can take some time.
-        if include_lims_data and HWR.beamline.lims.lims_rest:
-            limsres = HWR.beamline.lims.lims_rest.get_dc(lims_id)
-
-        # Always add link to data, (no request made)
-        limsres["limsTaskLink"] = self.app.lims.get_dc_link(lims_id)
-
         res = {
             "label": parameters["label"],
             "strategy_name": parameters["strategy_name"],
@@ -437,14 +409,13 @@ class Queue(ComponentBase):
             "queueID": queueID,
             "checked": node.is_enabled(),
             "state": state,
-            "limsResultData": limsres,
         }
 
         return res
 
     def _handle_wf(self, sample_node, node, include_lims_data):
         queueID = node._node_id
-        enabled, state = self.get_node_state(queueID)
+        _, state = self.get_node_state(queueID)
         parameters = node.parameters
         parameters.update(node.path_template.as_dict())
 
@@ -464,17 +435,6 @@ class Queue(ComponentBase):
             parameters["path"], parameters["fileName"]
         )
 
-        limsres = {}
-        lims_id = self.app.NODE_ID_TO_LIMS_ID.get(node._node_id, "null")
-
-        # Only add data from lims if explicitly asked for, since
-        # its a operation that can take some time.
-        if include_lims_data and HWR.beamline.lims.lims_rest:
-            limsres = HWR.beamline.lims.lims_rest.get_dc(lims_id)
-
-        # Always add link to data, (no request made)
-        limsres["limsTaskLink"] = self.app.lims.get_dc_link(lims_id)
-
         res = {
             "label": parameters["label"],
             "type": "Workflow",
@@ -485,14 +445,13 @@ class Queue(ComponentBase):
             "queueID": queueID,
             "checked": node.is_enabled(),
             "state": state,
-            "limsResultData": limsres,
         }
 
         return res
 
     def _handle_xrf(self, sample_node, node):
         queueID = node._node_id
-        enabled, state = self.get_node_state(queueID)
+        _, state = self.get_node_state(queueID)
         parameters = {
             "countTime": node.count_time,
             "shape": node.shape,
@@ -513,7 +472,6 @@ class Queue(ComponentBase):
         parameters["fullPath"] = os.path.join(
             parameters["path"], parameters["fileName"]
         )
-        model, entry = self.get_entry(queueID)
 
         res = {
             "label": "XRF Scan",
@@ -531,7 +489,7 @@ class Queue(ComponentBase):
 
     def _handle_energy_scan(self, sample_node, node):
         queueID = node._node_id
-        enabled, state = self.get_node_state(queueID)
+        _, state = self.get_node_state(queueID)
         parameters = {
             "element": node.element_symbol,
             "edge": node.edge,
@@ -580,18 +538,7 @@ class Queue(ComponentBase):
         parameters.update(refp)
 
         queueID = node._node_id
-        enabled, state = self.get_node_state(queueID)
-
-        limsres = {}
-        lims_id = self.app.NODE_ID_TO_LIMS_ID.get(node._node_id, "null")
-
-        # Only add data from lims if explicitly asked for, since
-        # its a operation that can take some time.
-        if include_lims_data and HWR.beamline.lims.lims_rest:
-            limsres = HWR.beamline.lims.lims_rest.get_dc(lims_id)
-
-        # Always add link to data, (no request made)
-        limsres["limsTaskLink"] = self.app.lims.get_dc_link(lims_id)
+        _, state = self.get_node_state(queueID)
 
         originID, task = self._handle_diffraction_plan(node, sample_node)
 
@@ -605,7 +552,6 @@ class Queue(ComponentBase):
             "taskIndex": self.node_index(node)["idx"],
             "queueID": node._node_id,
             "state": state,
-            "limsResultData": limsres,
             "diffractionPlan": task,
             "diffractionPlanID": originID,
         }
@@ -613,13 +559,11 @@ class Queue(ComponentBase):
         return res
 
     def _handle_diffraction_plan(self, node, sample_node):
-        model, entry = self.get_entry(node._node_id)
+        model, _ = self.get_entry(node._node_id)
         originID = model.get_origin()
         tasks = []
 
-        if len(model.diffraction_plan) == 0:
-            return (-1, {})
-        else:
+        if len(model.diffraction_plan) > 0:
             collections = model.diffraction_plan[0]  # a list of lists
 
             for col in collections:
@@ -642,7 +586,7 @@ class Queue(ComponentBase):
             wedges.append(self._handle_dc(sample_node, child))
 
         queueID = node._node_id
-        enabled, state = self.get_node_state(queueID)
+        _, state = self.get_node_state(queueID)
 
         res = {
             "label": "Interleaved",
@@ -668,7 +612,7 @@ class Queue(ComponentBase):
 
         for child in node.get_children():
             for _c in child.get_children():
-                child_enabled, child_state = self.get_node_state(_c._node_id)
+                _, child_state = self.get_node_state(_c._node_id)
                 children_states.append(child_state)
 
         if RUNNING in children_states:
@@ -755,9 +699,7 @@ class Queue(ComponentBase):
             elif isinstance(node, qmo.TaskGroup) and node.interleave_num_images:
                 result.append(self._handle_interleaved(sample_node, node))
             elif isinstance(node, qmo.TaskNode) and node.task_data:
-                result.append(
-                    self._handle_task_node(sample_node, node, include_lims_data)
-                )
+                result.append(self._handle_task_node(sample_node, node))
             else:
                 result.extend(self.queue_to_dict_rec(node, include_lims_data))
 
@@ -813,10 +755,10 @@ class Queue(ComponentBase):
         for sid, tindex in item_pos_list:
             if tindex in ["undefined", None]:
                 node_id = current_queue[sid]["queueID"]
-                model, entry = self.get_entry(node_id)
+                _, entry = self.get_entry(node_id)
             else:
                 node_id = current_queue[sid]["tasks"][int(tindex)]["queueID"]
-                model, entry = self.get_entry(node_id)
+                _, entry = self.get_entry(node_id)
 
                 # Get the TaskGroup of the item, there is currently only one
                 # task per TaskGroup so we have to remove the entire TaskGroup
@@ -986,12 +928,11 @@ class Queue(ComponentBase):
 
         Each item (dictionary) describes either a sample or a task.
         """
-        children = []
-
         for item in item_list:
             item_t = item["type"]
-            # If the item a sample, then add it and its tasks. If its not, get the
-            # node id for the sample of the new task and append it to the sample
+            # If the item is a sample, then add it and its tasks.
+            # Otherwise, get the node id for the sample of the
+            # new task and append it to the sample.
             sample_id = str(item["sampleID"])
 
             if item_t == "Sample":
@@ -1006,7 +947,6 @@ class Queue(ComponentBase):
 
                 if tasks:
                     self._queue_add_item_rec(tasks, sample_node_id)
-                    children.extend(tasks)
 
             else:
                 if not sample_node_id:
@@ -1095,6 +1035,15 @@ class Queue(ComponentBase):
         params = task_data["parameters"]
         acq.acquisition_parameters.set_from_dict(params)
 
+        processing_params = model.processing_parameters
+        processing_params.space_group = params.get("space_group", "")
+        processing_params.cell_a = params.get("cellA", "")
+        processing_params.cell_alpha = params.get("cellAlpha", "")
+        processing_params.cell_b = params.get("cellB", "")
+        processing_params.cell_beta = params.get("cellBeta", "")
+        processing_params.cell_c = params.get("cellC", "")
+        processing_params.cell_gamma = params.get("cellGamma", "")
+
         ftype = HWR.beamline.detector.get_property("file_suffix")
         ftype = ftype if ftype else ".?"
 
@@ -1418,10 +1367,13 @@ class Queue(ComponentBase):
         model.element_symbol = params.get("element", "")
         model.edge = params.get("edge", "")
 
+        # MXCuBE Web specific shape attribute
+        model.shape = params["shape"]
+
         model.set_enabled(task_data["checked"])
         entry.set_enabled(task_data["checked"])
 
-    def _create_dc(self, task):
+    def _create_dc(self):
         """
         Creates a data collection model and its corresponding queue entry from
         a dict with collection parameters.
@@ -1433,6 +1385,10 @@ class Queue(ComponentBase):
         dc_model = qmo.DataCollection()
         dc_model.set_origin(ORIGIN_MX3)
         dc_model.center_before_collect = True
+        dc_model.take_snapshots = HWR.beamline.collect.get_property(
+            "num_snapshots", self.app.DEFAULT_NUM_SNAPSHOTS
+        )
+
         dc_entry = qe.DataCollectionQueueEntry(Mock(), dc_model)
 
         return dc_model, dc_entry
@@ -1462,14 +1418,16 @@ class Queue(ComponentBase):
 
         entry = entry_cls(Mock(), entry_cls.QMO(task_data=data))
         entry.set_enabled(True)
-        return entry.get_data_model(), entry
 
-    def _create_wf(self, task):
+        model = entry.get_data_model()
+        model.set_origin(ORIGIN_MX3)
+
+        return model, entry
+
+    def _create_wf(self):
         """
-        Creates a workflow model and its corresponding queue entry from
-        a dict with collection parameters.
+        Creates a workflow model.
 
-        :param dict task: Collection parameters
         :returns: The tuple (model, entry)
         :rtype: Tuple
         """
@@ -1479,12 +1437,10 @@ class Queue(ComponentBase):
 
         return dc_model, dc_entry
 
-    def _create_gphl_wf(self, task):
+    def _create_gphl_wf(self):
         """
-        Creates a gphl workflow model and its corresponding queue entry from
-        a dict with collection parameters.
+        Creates a gphl workflow model.
 
-        :param dict task: Collection parameters
         :returns: The tuple (model, entry)
         :rtype: Tuple
         """
@@ -1498,10 +1454,9 @@ class Queue(ComponentBase):
 
         return dc_model, dc_entry
 
-    def _create_xrf(self, task):
+    def _create_xrf(self):
         """
-        Creates a XRFSpectrum model and its corresponding queue entry from
-        a dict with collection parameters.
+        Creates a XRFSpectrum model.
 
         :param dict task: Collection parameters
         :returns: The tuple (model, entry)
@@ -1513,7 +1468,7 @@ class Queue(ComponentBase):
 
         return xrf_model, xrf_entry
 
-    def _create_energy_scan(self, task, sample_model):
+    def _create_energy_scan(self, sample_model):
         """
         Creates a energy scan model and its corresponding queue entry from
         a dict with collection parameters.
@@ -1541,7 +1496,7 @@ class Queue(ComponentBase):
         sample_model, sample_entry = self.get_entry(node_id)
         params = task["parameters"]
 
-        refdc_model, refdc_entry = self._create_dc(task)
+        refdc_model, _ = self._create_dc()
         refdc_model.acquisitions[0].path_template.reference_image_prefix = "ref"
         refdc_model.set_name("refdc")
         char_params = qmo.CharacterisationParameters().set_from_dict(params)
@@ -1588,7 +1543,7 @@ class Queue(ComponentBase):
         :rtype: int
         """
         sample_model, sample_entry = self.get_entry(node_id)
-        dc_model, dc_entry = self._create_dc(task)
+        dc_model, dc_entry = self._create_dc()
         self.set_dc_params(dc_model, dc_entry, task, sample_model)
 
         group_model = qmo.TaskGroup()
@@ -1614,10 +1569,20 @@ class Queue(ComponentBase):
         """
         sample_model, sample_entry = self.get_entry(node_id)
         model, entry = self._create_queue_entry(task, task_name)
+        model.set_origin(ORIGIN_MX3)
 
         acq = model.acquisitions[0]
         params = task["parameters"]
 
+        processing_params = model.processing_parameters
+        processing_params.space_group = params.get("space_group", "")
+        processing_params.cell_a = params.get("cellA", "")
+        processing_params.cell_alpha = params.get("cellAlpha", "")
+        processing_params.cell_b = params.get("cellB", "")
+        processing_params.cell_beta = params.get("cellBeta", "")
+        processing_params.cell_c = params.get("cellC", "")
+        processing_params.cell_gamma = params.get("cellGamma", "")
+
         ftype = HWR.beamline.detector.get_property("file_suffix")
         ftype = ftype if ftype else ".?"
 
@@ -1639,7 +1604,8 @@ class Queue(ComponentBase):
             )
 
         full_path, process_path = HWR.beamline.session.get_full_path(
-            params.get("subdir", ""), task_name
+            os.path.join(params.get("subdir", ""), params.get("experiment_name", "")),
+            task_name,
         )
         acq.path_template.directory = full_path
         acq.path_template.process_directory = process_path
@@ -1675,7 +1641,7 @@ class Queue(ComponentBase):
         parent_model, parent_entry = self.get_entry(node_id)
         sample_model = parent_model.get_sample_node()
         if task["parameters"]["wfpath"] == "Gphl":
-            wf_model, dc_entry = self._create_gphl_wf(task)
+            wf_model, dc_entry = self._create_gphl_wf()
             self.set_gphl_wf_params(
                 wf_model,
                 dc_entry,
@@ -1683,7 +1649,7 @@ class Queue(ComponentBase):
                 parent_model.get_sample_node(),
             )
         else:
-            wf_model, dc_entry = self._create_wf(task)
+            wf_model, dc_entry = self._create_wf()
 
         group_model = qmo.TaskGroup()
         group_model.set_origin(ORIGIN_MX3)
@@ -1727,7 +1693,7 @@ class Queue(ComponentBase):
 
         for wedge in task["parameters"]["wedges"]:
             wc = wc + 1
-            dc_model, dc_entry = self._create_dc(wedge)
+            dc_model, dc_entry = self._create_dc()
             self.set_dc_params(dc_model, dc_entry, wedge, sample_model)
 
             # Add wedge prefix to path
@@ -1752,7 +1718,7 @@ class Queue(ComponentBase):
         :rtype: int
         """
         sample_model, sample_entry = self.get_entry(node_id)
-        xrf_model, xrf_entry = self._create_xrf(task)
+        xrf_model, xrf_entry = self._create_xrf()
         self.set_xrf_params(xrf_model, xrf_entry, task, sample_model)
 
         group_model = qmo.TaskGroup()
@@ -1779,7 +1745,7 @@ class Queue(ComponentBase):
         :rtype: int
         """
         sample_model, sample_entry = self.get_entry(node_id)
-        escan_model, escan_entry = self._create_energy_scan(task, sample_model)
+        escan_model, escan_entry = self._create_energy_scan(sample_model)
         self.set_energy_scan_params(escan_model, escan_entry, task, sample_model)
 
         group_model = qmo.TaskGroup()
@@ -1810,46 +1776,15 @@ class Queue(ComponentBase):
         HWR.beamline.queue_model.clear_model("plate")
         HWR.beamline.queue_model.select_model("ispyb")
 
-    def save_queue(self, session, redis=redis.Redis()):
-        """
-        Saves the current HWR.beamline.queue_model (HWR.beamline.queue_model) into a redis database.
-        The queue that is saved is the pickled result returned by queue_to_dict
-
-        :param session: Session to save queue for
-        :param redis: Redis database
-
-        """
-        proposal_id = getattr(current_user, "proposal", None)
-
-        if proposal_id is not None:
-            # List of samples dicts (containing tasks) sample and tasks have same
-            # order as the in queue HO
-            queue = self.queue_to_dict(HWR.beamline.queue_model.get_model_root())
-            redis.set("self.app.queue:%d" % proposal_id, pickle.dumps(queue))
-
-    def load_queue(self, session, redis=redis.Redis()):
-        """
-        Loads the queue belonging to session <session> into redis db <redis>
-
-        :param session: Session for queue to load
-        :param redis: Redis database
-        """
-        proposal_id = getattr(current_user, "proposal", None)
-
-        if proposal_id is not None:
-            serialized_queue = redis.get("self.app.queue:%d" % proposal_id)
-            queue = pickle.loads(serialized_queue)
-            self.load_queue_from_dict(queue)
-
     def queue_model_child_added(self, parent, child):
         """
         Listen to the addition of elements to the queue model ('child_added').
         Add the corresponding entries to the queue if they are not already
-        added. Handels for instance the addition of reference collections for
+        added. Handles for instance the addition of reference collections for
         characterisations and workflows.
         """
-        parent_model, parent_entry = self.get_entry(parent._node_id)
-        child_model, child_entry = self.get_entry(child._node_id)
+        _, parent_entry = self.get_entry(parent._node_id)
+        child_model, _ = self.get_entry(child._node_id)
 
         # Origin is ORIGIN_MX3 if task comes from MXCuBE-3
         if child_model.get_origin() != ORIGIN_MX3:
@@ -1899,9 +1834,9 @@ class Queue(ComponentBase):
         for collection in collection_list:
             if isinstance(collection, qmo.DataCollection):
                 if collection.get_origin():
-                    origin_model, origin_entry = self.get_entry(collection.get_origin())
+                    origin_model, _ = self.get_entry(collection.get_origin())
                 else:
-                    origin_model, origin_entry = self.get_entry(char._node_id)
+                    origin_model, _ = self.get_entry(char._node_id)
 
                 collection.set_enabled(False)
 
@@ -1921,7 +1856,7 @@ class Queue(ComponentBase):
 
         self.app.server.emit("add_diff_plan", {"tasks": cols}, namespace="/hwr")
 
-    def set_auto_add_diffplan(self, autoadd, current_sample=None):
+    def set_auto_add_diffplan(self, autoadd):
         """
         Sets auto add diffraction plan flag, automatically add to the queue
         (True) or wait for user (False)
@@ -1940,7 +1875,7 @@ class Queue(ComponentBase):
             tasks = current_queue[sample]["tasks"]
             for t in tasks:
                 if t["type"] == "Characterisation":
-                    model, entry = self.get_entry(t["queueID"])
+                    _, entry = self.get_entry(t["queueID"])
                     entry.auto_add_diff_plan = autoadd
 
     def execute_entry_with_id(self, sid, tindex=None):
@@ -2091,7 +2026,7 @@ class Queue(ComponentBase):
             sample_data = current_queue[sample_id]
             self.enable_entry(sample_data["queueID"], flag)
 
-    def set_auto_mount_sample(self, automount, current_sample=None):
+    def set_auto_mount_sample(self, automount):
         """
         Sets auto mount next flag, automatically mount next sample in queue
         (True) or wait for user (False)
@@ -2136,7 +2071,6 @@ class Queue(ComponentBase):
         )
 
     def init_queue_settings(self):
-        self.app.NUM_SNAPSHOTS = HWR.beamline.collect.get_property("num_snapshots", 4)
         self.app.AUTO_MOUNT_SAMPLE = HWR.beamline.collect.get_property(
             "auto_mount_sample", False
         )
@@ -2220,17 +2154,12 @@ class Queue(ComponentBase):
         msg = "[QUEUE] Cleared  " + str(HWR.beamline.queue_model.get_model_root()._name)
         logging.getLogger("MX3.HWR").info(msg)
 
-    def set_queue(self, json_queue, session):
-        # Clear queue
-        # HWR.beamline.queue_model = clear_queue()
-
-        # Set new queue
+    def set_queue(self, json_queue):
         self.queue_add_item(json_queue)
-        self.save_queue(session)
 
     def queue_update_item(self, sqid, tqid, data):
         model, entry = self.get_entry(tqid)
-        sample_model, sample_entry = self.get_entry(sqid)
+        sample_model, _ = self.get_entry(sqid)
 
         if data["type"] == "DataCollection":
             self.set_dc_params(model, entry, data, sample_model)
@@ -2402,7 +2331,9 @@ class Queue(ComponentBase):
                 "inverse_beam": False,
                 "take_dark_current": True,
                 "skip_existing_images": False,
-                "take_snapshots": True,
+                "take_snapshots": HWR.beamline.collect.get_property(
+                    "num_snapshots", self.app.DEFAULT_NUM_SNAPSHOTS
+                ),
                 "helical": False,
                 "mesh": False,
                 "prefixTemplate": "{PREFIX}_{POSITION}",
@@ -2508,3 +2439,10 @@ class Queue(ComponentBase):
             result = ()
 
         return result
+
+    def set_num_snapshots(self, num_snapshots: int):
+        """Sets the number of snapshots to take during data collection
+        Args:
+            num_snapshots (int): number of snapshots to be taken
+        """
+        HWR.beamline.collect.number_of_snapshots = num_snapshots
