@@ -1,31 +1,18 @@
 # -*- coding: utf-8 -*-
 import logging
-import types
-import sys
-import os
-import inspect
-
-import PIL
-import gevent.event
-
-from flask import Response
-
 from io import StringIO
-import base64
-
-from mxcubeweb.core.util.convertutils import to_camel, from_camel
-
-from mxcubecore.queue_entry.base_queue_entry import CENTRING_METHOD
-from mxcubecore.BaseHardwareObjects import HardwareObjectState
-from mxcubecore.HardwareObjects.abstract.AbstractNState import (
-    AbstractNState,
-)
-
 
+import gevent.event
+import PIL
+from flask import Response
 from mxcubecore import HardwareRepository as HWR
+from mxcubecore.queue_entry.base_queue_entry import CENTRING_METHOD
 
 from mxcubeweb.core.components.component_base import ComponentBase
-
+from mxcubeweb.core.util.convertutils import (
+    from_camel,
+    to_camel,
+)
 
 SNAPSHOT_RECEIVED = gevent.event.Event()
 SNAPSHOT = None
@@ -118,12 +105,6 @@ class SampleView(ComponentBase):
         self._centring_point_id = None
         self.http_streamer = HttpStreamer()
 
-        enable_snapshots(
-            HWR.beamline.collect,
-            HWR.beamline.diffractometer,
-            HWR.beamline.sample_view,
-        )
-
         HWR.beamline.sample_view.connect("shapesChanged", self._emit_shapes_updated)
 
         zoom_motor = HWR.beamline.diffractometer.get_object_by_role("zoom")
@@ -265,9 +246,10 @@ class SampleView(ComponentBase):
 
         for shape in HWR.beamline.sample_view.get_shapes():
             s = shape.as_dict()
-            shape_dict.update({shape.id: s})
-
-        return {"shapes": to_camel(shape_dict)}
+            # shape key comes case lowered from the to_camel (2dp1), this breaks UI
+            # let's ensure it's upper case by only camel casing the dict data
+            shape_dict.update({shape.id: to_camel(s)})
+        return {"shapes": shape_dict}
 
     def get_shape_width_sid(self, sid):
         shape = HWR.beamline.sample_view.get_shape(sid)
@@ -278,11 +260,11 @@ class SampleView(ComponentBase):
 
         return shape
 
-    def shape_add_cell_result(self, sid, cell, result):
+    def shape_add_result(self, sid, result, data_file):
         from mxcubeweb.routes import signals
 
         shape = HWR.beamline.sample_view.get_shape(sid)
-        shape.set_cell_result(cell, result)
+        HWR.beamline.sample_view.set_grid_data(sid, result, data_file)
         signals.grid_result_available(to_camel(shape.as_dict()))
 
     def handle_grid_result(self, shape):
@@ -292,7 +274,6 @@ class SampleView(ComponentBase):
 
     def update_shapes(self, shapes):
         updated_shapes = []
-
         for s in shapes:
             shape_data = from_camel(s)
             pos = []
@@ -303,6 +284,8 @@ class SampleView(ComponentBase):
             # If shape does not exist add it
             if not shape:
                 refs, t = shape_data.pop("refs", []), shape_data.pop("t", "")
+                state = shape_data.pop("state", "SAVED")
+                user_state = shape_data.pop("user_state", "SAVED")
 
                 # Store pixels per mm for third party software, to facilitate
                 # certain calculations
@@ -347,13 +330,15 @@ class SampleView(ComponentBase):
                             pos.append(center_positions)
 
                         shape = HWR.beamline.sample_view.add_shape_from_mpos(
-                            pos, (x, y), t
+                            pos, (x, y), t, state, user_state
                         )
                     except Exception:
                         logging.getLogger("HWR.MX3").info(shape_data)
 
                 else:
-                    shape = HWR.beamline.sample_view.add_shape_from_refs(refs, t)
+                    shape = HWR.beamline.sample_view.add_shape_from_refs(
+                        refs, t, state, user_state
+                    )
 
             # shape will be none if creation failed, so we check if shape exists
             # before setting additional parameters
@@ -375,53 +360,6 @@ class SampleView(ComponentBase):
                 except Exception:
                     raise
 
-    def move_zoom_motor(self, pos):
-        zoom_motor = HWR.beamline.diffractometer.get_object_by_role("zoom")
-        if zoom_motor.get_state() != HardwareObjectState.READY:
-            return (
-                "motor is already moving",
-                406,
-                {
-                    "Content-Type": "application/json",
-                    "msg": "zoom already moving",
-                },
-            )
-
-        if isinstance(zoom_motor, AbstractNState):
-            zoom_motor.set_value(zoom_motor.value_to_enum(pos))
-        else:
-            zoom_motor.set_value(pos)
-
-        scales = HWR.beamline.diffractometer.get_pixels_per_mm()
-        return {"pixelsPerMm": [scales[0], scales[1]]}
-
-    def back_light_on(self):
-        motor = HWR.beamline.diffractometer.get_object_by_role("BackLightSwitch")
-        motor.set_value(motor.VALUES.IN)
-
-    def back_light_off(self):
-        motor = HWR.beamline.diffractometer.get_object_by_role("BackLightSwitch")
-        motor.set_value(motor.VALUES.OUT)
-
-    def front_light_on(self):
-        motor = HWR.beamline.diffractometer.get_object_by_role("FrontLightSwitch")
-        motor.set_value(motor.VALUES.IN)
-
-    def front_light_off(self):
-        motor = HWR.beamline.diffractometer.get_object_by_role("FrontLightSwitch")
-        motor.set_value(motor.VALUES.OUT)
-
-    def move_motor(self, motid, newpos):
-        motor = HWR.beamline.diffractometer.get_object_by_role(motid.lower())
-
-        if newpos == "stop":
-            motor.stop()
-            return True
-        else:
-            motor.set_value(float(newpos))
-
-            return True
-
     def start_auto_centring(self):
         """
         Start automatic (lucid) centring procedure.
@@ -503,115 +441,9 @@ class SampleView(ComponentBase):
     def set_centring_method(self, method):
         if method == CENTRING_METHOD.LOOP:
             msg = "Using automatic loop centring when mounting samples"
-            self.app.CENTRING_METHOD = CENTRING_METHOD.LOOP
+            HWR.beamline.queue_manager.centring_method = CENTRING_METHOD.LOOP
         else:
             msg = "Using click centring when mounting samples"
-            self.app.CENTRING_METHOD = CENTRING_METHOD.MANUAL
+            HWR.beamline.queue_manager.centring_method = CENTRING_METHOD.MANUAL
 
         logging.getLogger("user_level_log").info(msg)
-
-
-def enable_snapshots(collect_object, diffractometer_object, sample_view):
-    def _snapshot_received(data):
-        snapshot_jpg = data.get("data", "")
-
-        global SNAPSHOT
-        SNAPSHOT = base64.b64decode(snapshot_jpg)
-        SNAPSHOT_RECEIVED.set()
-
-    def _do_take_snapshot(filename, bw=False):
-        sample_view.save_snapshot(filename, overlay=False, bw=bw)
-
-    def save_snapshot(self, filename, bw=False):
-        sample_view.save_snapshot(filename, overlay=False, bw=bw)
-        # _do_take_snapshot(filename, bw)
-
-    def take_snapshots(self, snapshots=None, _do_take_snapshot=_do_take_snapshot):
-        from mxcubeweb.app import MXCUBEApplication as mxcube
-
-        if snapshots is None:
-            # called via AbstractCollect
-            dc_params = self.current_dc_parameters
-            move_omega_relative = diffractometer_object.move_omega_relative
-        else:
-            # called via AbstractMultiCollect
-            # calling_frame = inspect.currentframe()
-            calling_frame = inspect.currentframe().f_back.f_back
-
-            dc_params = calling_frame.f_locals["data_collect_parameters"]
-            move_omega_relative = diffractometer_object.phiMotor.set_value_relative
-
-        if dc_params["take_snapshots"]:
-            # The below does not work. NUM_SNAPSHOTS needs to e got in somehow
-            number_of_snapshots = mxcube.NUM_SNAPSHOTS
-        else:
-            number_of_snapshots = 0
-
-        if number_of_snapshots > 0:
-            if (
-                hasattr(diffractometer_object, "set_phase")
-                and diffractometer_object.get_current_phase() != "Centring"
-            ):
-                use_custom_snapshot_routine = diffractometer_object.get_property(
-                    "custom_snapshot_script_dir", None
-                )
-                if not use_custom_snapshot_routine:
-                    logging.getLogger("user_level_log").info(
-                        "Moving Diffractometer to CentringPhase Not done for tests (DN)"
-                    )
-
-                    diffractometer_object.set_phase("Centring", wait=True, timeout=200)
-
-            snapshot_directory = dc_params["fileinfo"]["archive_directory"]
-            if not os.path.exists(snapshot_directory):
-                try:
-                    self.create_directories(snapshot_directory)
-                except Exception:
-                    logging.getLogger("MX3.HWR").exception(
-                        "Collection: Error creating snapshot directory"
-                    )
-
-            logging.getLogger("user_level_log").info(
-                "Taking %d sample snapshot(s)" % number_of_snapshots
-            )
-
-            for snapshot_index in range(number_of_snapshots):
-                snapshot_filename = os.path.join(
-                    snapshot_directory,
-                    "%s_%s_%s.snapshot.jpeg"
-                    % (
-                        dc_params["fileinfo"]["prefix"],
-                        dc_params["fileinfo"]["run_number"],
-                        (snapshot_index + 1),
-                    ),
-                )
-                dc_params[
-                    "xtalSnapshotFullPath%i" % (snapshot_index + 1)
-                ] = snapshot_filename
-
-                try:
-                    logging.getLogger("MX3.HWR").info(
-                        "Taking snapshot number: %d" % (snapshot_index + 1)
-                    )
-                    _do_take_snapshot(snapshot_filename)
-                    # diffractometer.save_snapshot(snapshot_filename)
-                except Exception as ex:
-                    sys.excepthook(*sys.exc_info())
-                    raise RuntimeError(
-                        "Could not take snapshot '%s'",
-                        snapshot_filename,
-                    ) from ex
-
-                if number_of_snapshots > 1:
-                    move_omega_relative(90)
-                    diffractometer_object.wait_ready()
-
-    collect_object.take_crystal_snapshots = types.MethodType(
-        take_snapshots, collect_object
-    )
-
-    diffractometer_object.save_snapshot = types.MethodType(
-        save_snapshot, diffractometer_object
-    )
-
-    sample_view.set_ui_snapshot_cb(save_snapshot)
